@@ -62,9 +62,6 @@ CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 /* Drivers that need to access the PCI config space directly need this */
 #include "xf86Pci.h"
 
-/* This is used for module versioning */
-#include "xf86Version.h"
-
 /* All drivers using the vgahw module need this */
 #include "vgaHW.h"
 
@@ -83,7 +80,6 @@ CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include "xf86cmap.h"
 
 #include "fb.h"
-#include "fbpseudocolor.h"
 
 /* Needed by Resources Access Control (RAC) */
 #include "xf86RAC.h"
@@ -326,6 +322,7 @@ static PciChipsets NEOPCIchipsets[] = {
     { -1,	     -1,	     RES_UNDEFINED}
 };
 
+#ifdef HAVE_ISA
 static IsaChipsets NEOISAchipsets[] = {
     { NM2070,               RES_EXCLUSIVE_VGA },
     { NM2090,               RES_EXCLUSIVE_VGA },
@@ -335,6 +332,7 @@ static IsaChipsets NEOISAchipsets[] = {
     { NM2200,               RES_EXCLUSIVE_VGA },
     { -1,			RES_UNDEFINED }
 };
+#endif
 
 /* The options supported by the Neomagic Driver */
 typedef enum {
@@ -647,7 +645,8 @@ NEOProbe(DriverPtr drv, int flags)
 	    xfree(usedChips);
 	}
     }
-    
+
+#ifdef HAVE_ISA 
     /* Isa Bus */
 
     numUsed = xf86MatchIsaInstances(NEO_NAME,NEOChipsets,NEOISAchipsets,
@@ -678,11 +677,13 @@ NEOProbe(DriverPtr drv, int flags)
       }
       xfree(usedChips);
     }
+#endif
 
     xfree(devSections);
     return foundScreen;
 }
 
+#ifdef HAVE_ISA
 static int
 neoFindIsaDevice(GDevPtr dev)
 {
@@ -709,7 +710,7 @@ neoFindIsaDevice(GDevPtr dev)
 	return -1;
     }
 }
-
+#endif
 
 /* Mandatory */
 Bool
@@ -1810,9 +1811,6 @@ NEOScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
                          CMAP_PALETTED_TRUECOLOR | CMAP_RELOAD_ON_MODE_SWITCH))
 	return FALSE;
 
-	if (pScrn->depth == 16)
-	    xxSetup(pScreen,8, pScrn->depth, NULL, nPtr->accelSync); /*@!@*/
-
     racflag |= RAC_COLORMAP;
     if (nPtr->NeoHWCursorInitialized)
         racflag |= RAC_CURSOR;
@@ -2086,7 +2084,7 @@ neoMapMem(ScrnInfoPtr pScrn)
 		
 		if (nPtr->NeoMMIOAddr2 != 0){
 		    result = (void**)&nPtr->NeoMMIOBase2;
-		    int err = pci_device_map_range(nPtr->PciInfo,
+		    err = pci_device_map_range(nPtr->PciInfo,
 						   nPtr->NeoMMIOAddr2,
 						   0x100000L,
 						   PCI_DEV_MAP_FLAG_WRITABLE,
